@@ -3,7 +3,7 @@ from typing import TYPE_CHECKING
 from starlette.middleware.gzip import GZipMiddleware as StarletteGzipMiddleware
 
 if TYPE_CHECKING:
-    from starlette.types import ASGIApp
+    from starlite.types import ASGIApp
 
 
 class GZipMiddleware(StarletteGzipMiddleware):
